Singleflight

Struct Singleflight 

pub struct Singleflight<T> { /* private fields */ }
Singleflight prevents the “Cache Stampede” effect (Dogpile effect). If multiple requests for the same key arrive simultaneously, only the first one executes the future. The others wait and receive the result of the first one.

Implementations

Source

impl<T: Clone + Send + Sync + 'static> Singleflight<T>

pub fn new() -> Self

pub async fn execute<F, Fut>(&self, key: &str, fut: F) -> Result<T, AppError>
where F: FnOnce() -> Fut, Fut: Future<Output = Result<T, AppError>> + Send + 'static,

Executes the provided async closure fut for the given key, or waits for an existing execution to finish and returns its result.