Crate ferrox_singleflight
ferrox_
singleflight
0.1.0
All Items
Crate Items
Structs
Crate
ferrox_
singleflight
Structs

Singleflight
Singleflight prevents the “Cache Stampede” effect (Dogpile effect). If multiple requests for the same key arrive simultaneously, only the first one executes the future. The others wait and receive the result of the first one.