pub struct Singleflight<T> { /* private fields */ }Expand description
Singleflight prevents the “Cache Stampede” effect (Dogpile effect). If multiple requests for the same key arrive simultaneously, only the first one executes the future. The others wait and receive the result of the first one.
Implementations